BLOOD_BAR_POSITION = [
    [None, [56, 322], [168, 322], [280, 322], [392, 322], [504, 322], [616, 322]],
    [None, [60, 142], [60, 217], [60, 292], [60, 367], [60, 442], [60, 517]],
]  # 血条的坐标

FLEET_POSITION = (
    None,
    (56, 222),
    (168, 222),
    (280, 222),
    (392, 222),
    (504, 222),
    (616, 222),
)  # 舰队每船的位置
"""扫描舰船类型的区域
    [0] 表示演习的扫描区域
    [1] 表示索敌界面的扫描区域
    每个列表的六个四元组为 (left, top, right, button)
"""
TYPE_SCAN_AREA = [
    [
        (277, 312, 309, 328),
        (380, 312, 412, 328),
        (483, 312, 515, 328),
        (587, 312, 619, 328),
        (690, 312, 722, 328),
        (793, 312, 825, 328),
    ],
    [
        (39, 156, 71, 172),
        (322, 156, 354, 172),
        (39, 245, 71, 261),
        (322, 245, 354, 261),
        (39, 334, 71, 350),
        (322, 334, 354, 350),
    ],
]
